/** ********************************************************************************************************************
 * @file        bp_api_sys.h
 * @author      Briowireless, Inc.
 * @date        2016-10-28
 * @brief       API layer for SYSTEM requests to the BitPipe, and defining callback prototypes for replies and
 *               asynchronous posts sent from the BitPipe.
 *              See the BitPipe Serial API document for more information on requests below.
 * @version     API V1
 * @copyright   Briowireless, Inc., 2016, Licensed under BSD license. See LICENSE file for more details.
 *
 ** *******************************************************************************************************************/
#ifndef __BP_API_SYS_H__
#define __BP_API_SYS_H__


// Include directives  -------------------------------------------------------------------------------------------------

#include <platform_defs.h>
#include <message_protocol/message_protocol.h>


// Preprocessor definitions --------------------------------------------------------------------------------------------

#define BP_API_SYS_SET_UART_SPEED__SPEED_115200                                 0x00    ///< 115200 bps (Factory default value)
#define BP_API_SYS_SET_UART_SPEED__SPEED_9600                                   0x01    ///< 9600 bps
#define BP_API_SYS_SET_UART_SPEED__SPEED_460800                                 0x02    ///< 460800 bps


// Global Type definitions ---------------------------------------------------------------------------------------------

typedef void (*bp_api_sys_error_report_post)(uint8_t seq_nr, uint8_t facility, uint8_t err_nr);
typedef void (*bp_api_sys_set_max_payload_sz_reply)(uint8_t seq_nr, uint8_t status);
typedef void (*bp_api_sys_set_uart_speed_reply)(uint8_t seq_nr, uint8_t status);


// Public Functions ----------------------------------------------------------------------------------------------------

uint8_t bp_api_sys_set_max_payload_sz(mp_seq_nr* seq_nr, uint16_t max_payload_sz);
uint8_t bp_api_sys_set_uart_speed(mp_seq_nr* seq_nr, uint8_t uart_speed);


#endif // __BP_API_SYS_H__
