/** ********************************************************************************************************************
 * @file        platform_defs.h
 * @author      Briowireless, Inc.
 * @date        2016-10-28
 * @brief       This file ensures that types used by the SDK layer are defined.
 *              The SDK uses the 'stdint.h' types standard. If your platform doesn't contain that include file, you
 *               should explicitely define them below here.
 * @copyright   Briowireless, Inc., 2016, Licensed under BSD license. See LICENSE file for more details.
 *
 ** *******************************************************************************************************************/
#ifndef __PLATFORM_DEFS_H__
#define __PLATFORM_DEFS_H__


// Include directives  -------------------------------------------------------------------------------------------------

#include <stdint.h>                                 // Standard integer types.
#include <stdio.h>                                  // For P_DEBUG, P_INFO, P_WARN and P_ERR macros below.
#include <string.h>                                 // for memcpy()


// Preprocessor definitions --------------------------------------------------------------------------------------------

// The general idea with the print macros below, is that you could do conditional logging based on a log priority. This
//  is not implemented in this SDK, because that's often specific to a platform or target system.
// Also, when running samples, the console output is much more legible when the filename is not printed (the printf
//  flavor is much more legible), however when integrating the SDK in your implementation, the other definition may
//  be more debug-friendly.
#if 0

#define P_DEBUG(FMT, ...)   printf("%s: " FMT, __FILE__, ##__VA_ARGS__)
#define P_INFO(FMT, ...)    printf("%s: " FMT, __FILE__, ##__VA_ARGS__)
#define P_WARN(FMT, ...)    printf("%s: " FMT, __FILE__, ##__VA_ARGS__)
#define P_ERR(FMT, ...)     printf("%s: " FMT, __FILE__, ##__VA_ARGS__)

#else

#define P_DEBUG             printf
#define P_INFO              printf
#define P_WARN              printf
#define P_ERR               printf

#endif


// Global Type definitions ---------------------------------------------------------------------------------------------

// If your platform doesn't have stdint.h definitions, define them here.


#endif  // __PLATFORM_DEFS_H__
